#!/bin/sh
################################################################################
## 	Licensed Materials - Property of IBM
##
##    TIVOCIT00
##
## 	(C) Copyright IBM Corp. 2005-2011 All Rights Reserved.
##
##	US Government Users Restricted Rights - Use, duplication,
## 	or disclosure restricted by GSA ADP Schedule Contract with
## 	IBM Corp.
##
##    Version: src/enabler/VMWare/linux/wenvmw.sh, enabler, cit_2.7fp2, 20120702v27fp2
##    Build date: 12/07/02 12:58:00
##
################################################################################

exec 2>&- # close stderr

# VMware Server was found and is a supported version
VMWARE_FOUND=0

# VMware Server not found on host system
VMWARE_NOT_FOUND=100

# VMware Server version is not compliant
VMWARE_NOT_SUPPORTED=105

# VmPerl Scripting API not found or configured properly
VMPERL_NOT_FOUND=120

function usage()
{
    echo "Usage: $1 [-v | --verbose | --debug] [-r | -ro]"
    echo "            [ -vm <vmx> ] [-f] [-t <timeout>]"
    echo ""
    echo "    -v, --verbose, --debug    - turns traces on. Traces are"
    echo "                                written into these files:"
    echo "                                    en_out.txt,"
    echo "                                    retr_out.txt,"
    echo "                                    en_report"
    echo ""
    echo "    -r                        - generate en_report.txt file."
    echo "                                Exclusive with -ro option."
    echo ""
    echo "    -ro                       - do not enable any VMs. Just"
    echo "                                generate en_report.txt file."
    echo ""
    echo "    -vm <vmx>                 - enable specified VM only -"
    echo "                                <vmx> is full path to VM's .vmx"
    echo "                                file as listed by vmware-cmd -l"
    echo "                                Ignored with -ro option."
    echo ""
    echo "    -f                        - do not check if a VM is running,"
    echo "                                always try to enable VMs (force)."
    echo "                                Ignored with -ro option."
    echo ""
    echo "    -t <timeout>              - do not run for more than <timeout>"
    echo "                                seconds."
}

# redirects output to a file
function verbose()
{
    if [ $VERBOSE -eq 1 ]; then
        echo $1 >> $OUTPUTFILE
    fi
}

function do_exit()
{
    if [ -z "$CACHE_LD_LIBRARY_PATH" ]; then
        unset -v LD_LIBRARY_PATH
    else
        LD_LIBARY_PATH=$CACHE_LD_LIBRARY_PATH
    fi

    verbose "----------------------------------------------------------"
    verbose "Finished on `date`"
    verbose "----------------------------------------------------------"
    
    exit $1
}

# checks if a VMware Server is available
function checkVMware()
{
    # if VMware ESX 2.5.x Server is installed via RPM this variable is not empty
    VMWAREESX_RPM=`rpm -qa | grep -i vmware-esx-[2-4]\.[0-9]\..-`

    # if VMware GSX 3.[1-9].x Server is installed via RPM this variable is not empty
    VMWAREGSX_RPM=`rpm -qa | grep -i vmware-gsx-[2-3]\.[1-9]\..-`

    # if VMware GSX 3.[1-9].x Server is installed via RPM this variable is not empty
    VMWARESERVER_RPM=`rpm -qa | grep -i vmware-server-1\.[0-9]\..-`

    #if ESX 4.x
    VMWAREESX_4_RPM=`rpm -qa | grep -i vmware-esx-vmware-release-4-4\.[0-9]`
    
    # checks for a non RPM installation of VMware Servers
    if [ -z "$VMWAREESX_RPM" ] && [ -z "$VMWAREGSX_RPM" ] && [ -z "$VMWARESERVER_RPM" ] && [ -z "$VMWAREESX_4_RPM" ]; then

        #check if "wmware" command can be called from everywhere
        which vmware > /dev/null 2>&1

        # the command runs successful
        if [ $? -eq 0 ]; then

            # tries to obtain VMware ESX Server version
            VMWAREESX_VER=`vmware -v | grep -i vmware\ esx\ [2-4]\.[0-9]\..`

            # tries to obtain VMware GSX Server version
            VMWAREGSX_VER=`vmware -v | grep -i vmware\ gsx\ server\ 3\.[1-9]\..`

            # tries to obtain VMware GSX Server version
            VMWARESERVER_VER=`vmware -v | grep -i vmware\ server\ 1\.[0-9]\..`

            # checks for enabler supported versions
            if [ -z "$VMWAREESX_VER" ] && [ -z "$VMWAREGSX_VER" ] && [ -z "$VMWARESERVER_VER" ]; then

                verbose "OK: only VMware GSX 3.[1-9].x or ESX 2.5.x , ESX 3.x or ESX 4.x or VMvare Server 1.x are supported."
                return $VMWARE_NOT_SUPPORTED
            else
                verbose "OK: found VMware GSX 3.[1-9].x or ESX 2.5.x or ESX 3.x or ESX 4.x or VMware Server 1.X non RPM installation."
            fi
        else
            verbose "OK: VMware GSX or ESX or VMware Server not found on this system."
            return $VMWARE_NOT_FOUND
        fi
    else
        verbose "OK: found VMware GSX 3.1+ or ESX 2.5.x or ESX 3.x or ESX 4.x or VMware Server 1.X RPM installation."
    fi
    
    #check if VmPerl API is installed

    perl -e 'use VMware::VmPerl;' >/dev/null 2>&1
    if [ $? -ne 0 ]; then
        verbose "Warning: VmPerl Scripting API may not be installed. Please check retr_out.txt logs if enabler fails."
    fi

    return $VMWARE_FOUND;
}


VERBOSE=0
CITENABLER_REPORT=0
CITENABLER_REPORT_ONLY=0
CITENABLER_THE_VM=""
CITENABLER_FORCE=0

ALL_ARGS=$@

while true; do
    if [ "$1" == "-h" ] || [ "$1" == "-help" ] || [ "$1" == "--help" ]; then
        usage "$0"
        do_exit 0
    elif [ "$1" == "-v" ] || [ "$1" == "--verbose" ] || [ "$1" == "--debug" ]; then
        VERBOSE=1
        CITENABLER_REPORT=1
        shift
    elif [ "$1" == "-r" ]; then
        CITENABLER_REPORT=1
        shift
    elif [ "$1" == "-ro" ]; then
        CITENABLER_REPORT=1
        CITENABLER_REPORT_ONLY=1
        shift
    elif [ "$1" == "-vm" ]; then
        CITENABLER_THE_VM=$2
        if [ "$CITENABLER_THE_VM" == "" ] || [ `echo $CITENABLER_THE_VM | cut -c1-1` == "-" ]; then
            echo "ERROR! Please provide full path to VM's vmx file after -vm option."
            usage "$0"
            do_exit -1
        fi
        shift
        shift
    elif [ "$1" == "-f" ]; then
        CITENABLER_FORCE=1
        shift
    elif [ "$1" == "" ]; then
        break
    else
        echo "ERROR! Invalid argument: $1, aborting."
        usage "$0"
        do_exit -1
        break
    fi
done


# checks if CITENABLER_HOME is set
if [ -z "$CITENABLER_HOME" ]; then

    BASE_NAME=`basename "$0"`
    DIR_NAME=`dirname "$0"`

    cd "$DIR_NAME"

    if [ "`pwd`" != "/" ]; then
        FULL_NAME="`pwd`/$BASE_NAME"
    else
        FULL_NAME="/$BASE_NAME"
    fi

    # builds the home full path
    FULL_DIR=`dirname "$FULL_NAME"`
    CITENABLER_HOME="$FULL_DIR"

    export CITENABLER_HOME

#    cd -
fi

if [ ! -d "$CITENABLER_HOME" ]; then
    echo "$CITENABLER_HOME not exists or is not a directory"
    do_exit -1
fi

cd "$CITENABLER_HOME"

OUTPUTFILE="./en_out.txt"

verbose ""
verbose "----------------------------------------------------------"
verbose "Started on `date`"
verbose "----------------------------------------------------------"

#validate configuration
if [ $CITENABLER_REPORT_ONLY -eq 1 ]; then

    if [ -n "CITENABLER_THE_VM" ]; then
        verbose "Warning! In report only mode - ignoring -vm (single VM) option"
    fi
    CITENABLER_THE_VM=""
    
    if [ $CITENABLER_FORCE -eq 1 ]; then
        verbose "Warning! In report only mode - ignoring -f (force) option"
    fi
    CITENABLER_FORCE=0
fi

CITENABLER_FROM_WENVMW=1
export CITENABLER_FROM_WENVMW
export CITENABLER_THE_VM
export CITENABLER_REPORT
export CITENABLER_REPORT_ONLY
export CITENABLER_FORCE



checkVMware
VMWARE_CHECK=$?

# exits if VMware Server is not present
# or is it a not supported version
if [ $VMWARE_CHECK -ne $VMWARE_FOUND ]; then
    do_exit $VMWARE_CHECK
fi

# checks if dispatcher exists and is executable
if [ ! -x "$CITENABLER_HOME/dispatcher" ]; then
    verbose "ERROR: the file $CITENABLER_HOME/dispatcher does not exists or is not executable"
    do_exit -1
fi

#in case libstdc++ v.5 is not istalled in standard location, these are best guesses:
CACHE_LD_LIBRARY_PATH=$LD_LIBRARY_PATH
declare -x LD_LIBRARY_PATH="$LD_LIBRARY_PATH:/usr/lib/vmware/vpx:"

verbose "\$CITENABLER_HOME=$CITENABLER_HOME"


#restore arguments
n=0
for arg in $ALL_ARGS ; do 
    n=`expr $n + 1`
    eval arg$n="$arg"
done

# checks if dmidecode is avalable
if [ ! -e /usr/sbin/dmidecode ]; then
    "$CITENABLER_HOME/dispatcher" $arg1 $arg2 $arg3 $arg4 $arg5 $arg6 $arg7 $arg8 $arg9
else
    "$CITENABLER_HOME/dispatcher" --dmidecode $arg1 $arg2 $arg3 $arg4 $arg5 $arg6 $arg7 $arg8 $arg9
fi

RC=$?

if [ $RC -ne 0 ]; then
    rm -f out
    verbose "ERROR: dispatcher return code = $RC"
    do_exit $RC
fi

RETR_STATUS=`grep STATUS=2 <en_report.txt | awk 'BEGIN {FS="STATUS="}{print $2}'`

do_exit $RETR_STATUS
